@@ -13,7 +13,10 @@
 # Copyright (c) 2018 Bryce Guinta <bryce.paul.guinta@gmail.com>
 # Copyright (c) 2018 Daniel Colascione <dancol@dancol.org>
 # Copyright (c) 2019 Hugo van Kemenade <hugovk@users.noreply.github.com>
+# Copyright (c) 2021 Tushar Sadhwani <86737547+tushar-deepsource@users.noreply.github.com>
 # Copyright (c) 2021 Pierre Sassoulas <pierre.sassoulas@gmail.com>
+# Copyright (c) 2021 pre-commit-ci[bot] <bot@noreply.github.com>
+# Copyright (c) 2021 Daniël van Noord <13665637+DanielNoord@users.noreply.github.com>
 # Copyright (c) 2021 David Liu <david@cs.toronto.edu>
 # Copyright (c) 2021 doranid <ddandd@gmail.com>
 # Copyright (c) 2021 Marc Mueller <30130371+cdce8p@users.noreply.github.com>
@@ -366,7 +369,7 @@ class UnboundMethod(Proxy):
     special_attributes = lazy_descriptor(lambda: objectmodel.UnboundMethodModel())
 
     def __repr__(self):
-        frame = self._proxied.parent.frame()
+        frame = self._proxied.parent.frame(future=True)
         return "<{} {} of {} at 0x{}".format(
             self.__class__.__name__, self._proxied.name, frame.qname(), id(self)
         )
@@ -402,7 +405,7 @@ class UnboundMethod(Proxy):
         # instance of the class given as first argument.
         if (
             self._proxied.name == "__new__"
-            and self._proxied.parent.frame().qname() == "builtins.object"
+            and self._proxied.parent.frame(future=True).qname() == "builtins.object"
         ):
             if caller.args:
                 node_context = context.extra_context.get(caller.args[0])
@@ -423,7 +426,7 @@ class BoundMethod(UnboundMethod):
     special_attributes = lazy_descriptor(lambda: objectmodel.BoundMethodModel())
 
     def __init__(self, proxy, bound):
-        UnboundMethod.__init__(self, proxy)
+        super().__init__(proxy)
         self.bound = bound
 
     def implicit_parameters(self):
@@ -575,12 +578,10 @@ class Generator(BaseInstance):
         return True
 
     def __repr__(self):
-        return "<Generator({}) l.{} at 0x{}>".format(
-            self._proxied.name, self.lineno, id(self)
-        )
+        return f"<Generator({self._proxied.name}) l.{self.lineno} at 0x{id(self)}>"
 
     def __str__(self):
-        return "Generator(%s)" % self._proxied.name
+        return f"Generator({self._proxied.name})"
 
 
 class AsyncGenerator(Generator):
@@ -593,9 +594,7 @@ class AsyncGenerator(Generator):
         return "AsyncGenerator"
 
     def __repr__(self):
-        return "<AsyncGenerator({}) l.{} at 0x{}>".format(
-            self._proxied.name, self.lineno, id(self)
-        )
+        return f"<AsyncGenerator({self._proxied.name}) l.{self.lineno} at 0x{id(self)}>"
 
     def __str__(self):
-        return "AsyncGenerator(%s)" % self._proxied.name
+        return f"AsyncGenerator({self._proxied.name})"
