@@ -4,6 +4,7 @@
 # Copyright (c) 2018 Ioana Tagirta <ioana.tagirta@gmail.com>
 # Copyright (c) 2019 Hugo van Kemenade <hugovk@users.noreply.github.com>
 # Copyright (c) 2020-2021 hippo91 <guillaume.peillex@gmail.com>
+# Copyright (c) 2021 John Belmonte <john@neggie.net>
 # Copyright (c) 2021 Pierre Sassoulas <pierre.sassoulas@gmail.com>
 # Copyright (c) 2021 Marc Mueller <30130371+cdce8p@users.noreply.github.com>
 
@@ -15,7 +16,7 @@ from astroid.builder import extract_node, parse
 from astroid.const import PY39_PLUS
 from astroid.exceptions import AttributeInferenceError
 from astroid.manager import AstroidManager
-from astroid.scoped_nodes import ClassDef
+from astroid.nodes.scoped_nodes import ClassDef
 
 
 def _collections_transform():
@@ -61,7 +62,7 @@ def _deque_mock():
         def __copy__(self): return deque(self.iterable)
         def copy(self): return deque(self.iterable)
         def index(self, x, start=0, end=0): return 0
-        def insert(self, x, i): pass
+        def insert(self, i, x): pass
         def __add__(self, other): pass
         def __iadd__(self, other): pass
         def __mul__(self, other): pass
