@@ -6,18 +6,24 @@
 # Copyright (c) 2015 Florian Bruhin <me@the-compiler.org>
 # Copyright (c) 2016 Jakub Wilk <jwilk@jwilk.net>
 # Copyright (c) 2018 Nick Drozd <nicholasdrozd@gmail.com>
-# Copyright (c) 2021 pre-commit-ci[bot] <bot@noreply.github.com>
+# Copyright (c) 2021 Daniël van Noord <13665637+DanielNoord@users.noreply.github.com>
 # Copyright (c) 2021 Pierre Sassoulas <pierre.sassoulas@gmail.com>
 # Copyright (c) 2021 Marc Mueller <30130371+cdce8p@users.noreply.github.com>
+# Copyright (c) 2021 pre-commit-ci[bot] <bot@noreply.github.com>
 
 # Licensed under the LGPL: https://www.gnu.org/licenses/old-licenses/lgpl-2.1.en.html
-# For details: https://github.com/PyCQA/astroid/blob/master/LICENSE
+# For details: https://github.com/PyCQA/astroid/blob/main/LICENSE
 
 """This module contains some mixins for the different nodes.
 """
 import itertools
+from typing import TYPE_CHECKING, Optional
 
-from astroid import decorators, exceptions
+from astroid import decorators
+from astroid.exceptions import AttributeInferenceError
+
+if TYPE_CHECKING:
+    from astroid import nodes
 
 
 class BlockRangeMixIn:
@@ -43,9 +49,9 @@ class BlockRangeMixIn:
 class FilterStmtsMixin:
     """Mixin for statement filtering and assignment type"""
 
-    def _get_filtered_stmts(self, _, node, _stmts, mystmt):
+    def _get_filtered_stmts(self, _, node, _stmts, mystmt: Optional["nodes.Statement"]):
         """method used in _filter_stmts to get statements and trigger break"""
-        if self.statement() is mystmt:
+        if self.statement(future=True) is mystmt:
             # original node's statement is the assignment, only keep
             # current node (gen exp, list comp)
             return [node], True
@@ -59,11 +65,13 @@ class AssignTypeMixin:
     def assign_type(self):
         return self
 
-    def _get_filtered_stmts(self, lookup_node, node, _stmts, mystmt):
+    def _get_filtered_stmts(
+        self, lookup_node, node, _stmts, mystmt: Optional["nodes.Statement"]
+    ):
         """method used in filter_stmts"""
         if self is mystmt:
             return _stmts, True
-        if self.statement() is mystmt:
+        if self.statement(future=True) is mystmt:
             # original node's statement is the assignment, only keep
             # current node (gen exp, list comp)
             return [node], True
@@ -111,7 +119,7 @@ class ImportFromMixin(FilterStmtsMixin):
                 _asname = name
             if asname == _asname:
                 return name
-        raise exceptions.AttributeInferenceError(
+        raise AttributeInferenceError(
             "Could not find original name for {attribute} in {target!r}",
             target=self,
             attribute=asname,
