@@ -13,6 +13,7 @@
 # Copyright (c) 2020-2021 hippo91 <guillaume.peillex@gmail.com>
 # Copyright (c) 2020 Becker Awqatty <bawqatty@mide.com>
 # Copyright (c) 2020 Robin Jarry <robin.jarry@6wind.com>
+# Copyright (c) 2021 Daniël van Noord <13665637+DanielNoord@users.noreply.github.com>
 # Copyright (c) 2021 Pierre Sassoulas <pierre.sassoulas@gmail.com>
 # Copyright (c) 2021 Marc Mueller <30130371+cdce8p@users.noreply.github.com>
 # Copyright (c) 2021 Andrew Haigh <hello@nelf.in>
@@ -32,8 +33,9 @@ import types
 import warnings
 from typing import List, Optional
 
-from astroid import bases, node_classes, nodes
+from astroid import bases, nodes
 from astroid.manager import AstroidManager
+from astroid.nodes import node_classes
 
 # the keys of CONST_CLS eg python builtin types
 _CONSTANTS = tuple(node_classes.CONST_CLS)
@@ -105,7 +107,7 @@ def attach_import_node(node, modname, membername):
     _attach_local_node(node, from_node, membername)
 
 
-def build_module(name, doc=None):
+def build_module(name: str, doc: Optional[str] = None) -> nodes.Module:
     """create and initialize an astroid Module node"""
     node = nodes.Module(name, doc, pure_python=False)
     node.package = False
@@ -117,8 +119,7 @@ def build_class(name, basenames=(), doc=None):
     """create and initialize an astroid ClassDef node"""
     node = nodes.ClassDef(name, doc)
     for base in basenames:
-        basenode = nodes.Name()
-        basenode.name = base
+        basenode = nodes.Name(name=base)
         node.bases.append(basenode)
         basenode.parent = node
     return node
@@ -303,7 +304,12 @@ class InspectBuilder:
         self._done = {}
         self._module = None
 
-    def inspect_build(self, module, modname=None, path=None):
+    def inspect_build(
+        self,
+        module: types.ModuleType,
+        modname: Optional[str] = None,
+        path: Optional[str] = None,
+    ) -> nodes.Module:
         """build astroid from a living module (i.e. using inspect)
         this is used when there is no python source code available (either
         because it's a built-in module or because the .py is not available)
@@ -395,7 +401,7 @@ class InspectBuilder:
         except TypeError:
             modname = None
         if modname is None:
-            if name in ("__new__", "__subclasshook__"):
+            if name in {"__new__", "__subclasshook__"}:
                 # Python 2.5.1 (r251:54863, Sep  1 2010, 22:03:14)
                 # >>> print object.__new__.__module__
                 # None
